@@ -1,4 +1,4 @@
-/* $Id: main.c,v 1.29 2002/03/16 21:00:04 kevinv Exp $ */
+/* $Id: main.c,v 1.32.2.1 2003/01/13 10:37:16 gman Exp $ */
 
 /*
  *  Mike Hughes <mfh@psilord.com>
@@ -56,31 +56,48 @@ static gint client_die_cb (GnomeClient *client, gpointer client_data)
 	gtk_main_quit ();
 }
 
+const char **
+get_command_line_args (GnomeProgram *program)
+{
+	GValue value = { 0, };
+	poptContext ctx;
+
+	g_value_init (&value, G_TYPE_POINTER);
+	g_object_get_property (G_OBJECT (program), GNOME_PARAM_POPT_CONTEXT, &value);
+	ctx = g_value_get_pointer (&value);
+	g_value_unset (&value);
+
+	return poptGetArgs (ctx);
+}
+
 int main (int argc, char *argv[])
 {
     gint i;
     GDictApplet * applet = NULL;
     GnomeClient *client;
-
-    
-
-    static struct poptOption args[] = {
-        {"noapplet", 'a', POPT_ARG_NONE, 0, 0, "Legacy support - no longer is necessary", NULL},
-        {NULL, 0, 0, NULL, 0, NULL, NULL}
-    };
+    GnomeProgram *program;
+    const char **args;
 
     bindtextdomain(GETTEXT_PACKAGE, GNOMELOCALEDIR);
     bind_textdomain_codeset(GETTEXT_PACKAGE, "UTF-8");
     textdomain(GETTEXT_PACKAGE);
 
-    gnome_init_with_popt_table ("gnome-dictionary", VERSION, argc, argv,
-                                    args, 0, NULL);
+    program = gnome_program_init ("gnome-dictionary",VERSION,
+				  LIBGNOMEUI_MODULE,
+				  argc, argv,
+				  GNOME_PARAM_APP_DATADIR,DATADIR,NULL);
+
+	
 
     if ((client = gnome_master_client()) != NULL) {
             g_signal_connect (client, "save_yourself",
                               G_CALLBACK (save_yourself_cb),
                               (gpointer) argv[0]);
-            g_signal_connect (client, "die", G_CALLBACK (client_die_cb), NULL);
+	    /* FIXME: We should really connect to this, but gnome-session wants to 
+	     * remove non-reponsive clients after a timeout - in this case the 
+	     * client is busy trying to connect to the dict server
+             * g_signal_connect (client, "die", G_CALLBACK (client_die_cb), NULL);
+	     */
     }
     
     
@@ -91,11 +108,12 @@ int main (int argc, char *argv[])
     gdict_init_context ();
     defbox->context = context;
 
-    for (i = 1;  i < argc;  i++)
-            if (argv[i][0] != '-') {
-                gdict_defbox_lookup(defbox, argv[i]);
-                break;
-            }
+    args = get_command_line_args (program);
+
+    for (i = 0; args != NULL && args[i] != NULL; i++) {
+	    gdict_defbox_lookup(defbox, (char *)args[i]);
+	    break;
+    }
 
     gtk_widget_show(gdict_app);
     gtk_main();
